require 'addressable/uri'
require 'builder'
require 'faraday'
require 'faraday_middleware'
require 'json'
require 'json/jwt'
require 'rexml/document'
require 'securerandom'
require 'simple_oauth'
require 'oauth'
require 'cgi'

module IMS
  module LTI
    require_relative 'lti/converters'
    require_relative 'lti/errors'
    require_relative 'lti/models'
    require_relative 'lti/serializers'
    require_relative 'lti/services'
  end

  # The versions of LTI this library supports
  VERSIONS = %w{1.0 1.1}

  class InvalidLTIConfigError < StandardError
  end

  class XMLParseError < StandardError
  end

  # POST a signed oauth request with the given key/secret/data
  def self.post_service_request(key, secret, url, content_type, body)
    raise IMS::LTI::InvalidLTIConfigError, "" unless key && secret

    consumer = OAuth::Consumer.new(key, secret)
    token = OAuth::AccessToken.new(consumer)
    token.post(
            url,
            body,
            'Content-Type' => content_type
    )
  end

  # Generates a unique identifier
  def self.generate_identifier
    SecureRandom.uuid
  end
end


require 'ims/lti/extensions'
require 'ims/lti/launch_params'
require 'ims/lti/request_validator'
require 'ims/lti/tool_base'
require 'ims/lti/deprecated_role_checks'
require 'ims/lti/role_checks'
require 'ims/lti/tool_provider'
require 'ims/lti/tool_consumer'
require 'ims/lti/outcome_request'
require 'ims/lti/outcome_response'
require 'ims/lti/tool_config'
